@@ -1,7 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-
-#include "config.h"
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 
 #include <iostream>
 
@@ -11,6 +11,7 @@
 #include <dune/localfunctions/raviartthomas/raviartthomas03d.hh>
 #include <dune/localfunctions/raviartthomas/raviartthomaslfecache.hh>
 #include <dune/localfunctions/raviartthomas/raviartthomas12d.hh>
+#include <dune/localfunctions/raviartthomas.hh>
 
 #include <dune/localfunctions/test/test-localfe.hh>
 
@@ -19,13 +20,13 @@ int main(int argc, char** argv)
   bool success = true;
 
   Dune::RaviartThomasSimplexLocalFiniteElement<2,double,double> rt0simplex2dlfem(Dune::GeometryTypes::simplex(2),0);
-  TEST_FE(rt0simplex2dlfem);
+  TEST_FE3(rt0simplex2dlfem, DisableNone, 2);
 
   Dune::RaviartThomasSimplexLocalFiniteElement<2,double,double> rt1simplex2dlfem(Dune::GeometryTypes::simplex(2),1);
-  TEST_FE(rt1simplex2dlfem);
+  TEST_FE3(rt1simplex2dlfem, DisableNone,2);
 
   Dune::RaviartThomasSimplexLocalFiniteElement<3,double,double> rt0simplex3dlfem(Dune::GeometryTypes::simplex(3),0);
-  TEST_FE(rt0simplex3dlfem);
+  TEST_FE3(rt0simplex3dlfem,DisableNone,2);
 
   Dune::RaviartThomasCubeLocalFiniteElement<double,double,2,0> rt0cube2dlfem;
   TEST_FE(rt0cube2dlfem);
@@ -139,6 +140,27 @@ int main(int argc, char** argv)
     TEST_FE(rt1cube3dlfemDedicated);
   }
 
+  // Pyramid shapefunctions are not differentiable on the plane where xi[0]=xi[1].
+  // So let's skip test points on this plane
+  auto xySkip = [](const Dune::FieldVector<double,3>& xi){return std::abs(xi[0]-xi[1]) < 1e-8;};
+
+  Dune::RT0PyramidLocalFiniteElement<double,double> rt0pyramidlfemDedicated;
+  TEST_FE4(rt0pyramidlfemDedicated, DisableNone, 0, xySkip);
+  for (unsigned int s = 0; s < 32; s++)
+  {
+    Dune::RT0PyramidLocalFiniteElement<double,double> rt0pyramidlfemDedicated(s);
+    TEST_FE4(rt0pyramidlfemDedicated, DisableNone, 0, xySkip);
+  }
+
+  Dune::RT0PrismLocalFiniteElement<double,double> rt0prismlfemDedicated;
+  TEST_FE(rt0prismlfemDedicated);
+  for (unsigned int s = 0; s < 32; s++)
+  {
+    Dune::RT0PrismLocalFiniteElement<double,double> rt0prismlfemDedicated(s);
+    TEST_FE(rt0prismlfemDedicated);
+  }
+
+
   // Test the RaviartThomasLocalFiniteElementCache
   Dune::RaviartThomasLocalFiniteElementCache<double,double,2,0> lagrangeLFECache;
   TEST_FE(lagrangeLFECache.get(Dune::GeometryTypes::simplex(2)));
