@@ -1,6 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include <config.h>
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 
 #include <dune/geometry/type.hh>
 #include <dune/geometry/quadraturerules.hh>
@@ -44,7 +45,7 @@ bool test(unsigned int order)
   for (unsigned int o = 0; o <= order; ++o)
   {
     std::cout << "Testing " << geometry << " with order " << o << std::endl;
-    typedef Dune::OrthonormalBasisFactory<geometry.dim(),StorageField,ComputeField> BasisFactory;
+    typedef Dune::OrthonormalBasisFactory<geometry.dim(),double,double,StorageField,ComputeField> BasisFactory;
     const typename BasisFactory::Object &basis = *BasisFactory::template create<geometry>(o);
 
     const unsigned int size = basis.size( );
